#!/bin/bash

#SBATCH --job-name=
#SBATCH --mail-user=ploche@physik.fu-berlin.de
#SBATCH --mail-type=FAIL

#SBATCH --output=job_%x.out
#SBATCH --ntasks-per-node=10
#SBATCH --mem-per-cpu=1G
#SBATCH --time=1-10:00:00
#SBATCH --nodes=1
#SBATCH --partition=main
#SBATCH --gres=gpu:NGPU

set -e #Exit immediately if a command exits with a non-zero status

module load gromacs/single/2019
#gmx mdrun -cpi state.cpt -nt ${SLURM_NTASKS_PER_NODE} -maxh 33

# RDF Analysis
echo "RDF Analysis is run in background."
echo "Log files are saved to rdf_xx_x.log"

NBLOCKS=5
MAXT=20000
DT=$(( MAXT / NBLOCKS ))
TIMEFRAMES=($(seq 0 $DT $MAXT))

BEGIN=0
for i in $(seq 1 $NBLOCKS); do
    END=${TIMEFRAMES[$i]}
    ARGS="-f traj_comp.xtc -s topol.tpr -bin 0.01 -b $BEGIN -e $END"
    # Run RDF calculation in parallel
    gmx rdf $ARGS -sel KATION -ref KATION -o rdf_++_$i.xvg &> rdf_++_$i.log &
    gmx rdf $ARGS -sel KATION -ref ANION -o rdf_+-_$i.xvg &> rdf_+-_$i.log &
    gmx rdf $ARGS -sel KATION -ref SOL -selrpos mol_com -o rdf_+s_$i.xvg &> rdf_+s_$i.log &
    BEGIN=$END
    wait
done
