#!/bin/bash

# Builds the anion and kations folders for the g(r). 
# The ion sigma and epsilon parameters are taken from the ipython notebook.

set -e

module load gromacs/single/2019
BASE=$(realpath .)

# Lengths of all lists must be the same!
ION="Cl"

SIGMAS=( 0.445 )
EPSILONS=( 0.42 )

N=${#SIGMAS[@]}
N=$((N-1))

# Set watermodel
# 1: SPC      
# 2: SPC/E    
# 3: TIP3P     
# 4: TIP4P    
# 5: TIP4P/ε
WM_INDICES=( 2 )

for WM_INDEX in ${WM_INDICES[@]}; do
if [ $WM_INDEX == 1 ]; then 
    WM="spc"
    WGRO="spc216.gro"
elif [ $WM_INDEX == 2 ]; then
    WM="spce"
    WGRO="spc216.gro"
elif [ $WM_INDEX == 3 ]; then
    WM="tip3p"
    WGRO="spc216.gro"
elif [ $WM_INDEX == 4 ]; then
    WM="tip4p"
    WGRO="tip4p.gro"
elif [ $WM_INDEX == 5 ]; then
    WM="tip4pe"
    WGRO="tip4p.gro"
else
    echo "$WM_INDEX is not valid. Should be between 1 and 5." > /dev/stderr
    continue
fi

if [ ${#SIGMAS[@]} != ${#EPSILONS[@]} ]; then
    echo "The parameter lists do not have the same length." > /dev/stderr
    exit 2
fi  

mkdir -p $WM/$ION
cd $WM/$ION

for i in $(seq 0 $N); do
ION_SIGMA=${SIGMAS[$i]}
ION_EPSILON=${EPSILONS[$i]}

DIRNAME=sigma\_$ION_SIGMA\_epsilon\_$ION_EPSILON
mkdir -p $DIRNAME
cd $DIRNAME

    ln -sf $(realpath --relative-to="." "$BASE/..")/si.ff si.ff
    gmx -quiet solvate -box 2.5 2.5 2.5 -cs $WGRO
    gmx -quiet pdb2gmx -f out.gro << EOF
        1
        $WM_INDEX
EOF

    # Add custom ion parameters
    ION_NUMBER=$(cat si.ff/ffnonbonded.itp | grep $ION | awk '{print $2}')
    ION_MASS=$(cat si.ff/atomtypes.atp | grep $ION | awk '{print $2}')
    sed -i "/forcefield.itp/a [ atomtypes ]\n $ION  $ION_NUMBER  $ION_MASS  0.0000 A  $ION_SIGMA $ION_EPSILON\n" topol.top


    gmx grompp -c conf.gro -f $BASE/input/em.mdp -o ion.tpr -maxwarn 2
    gmx genion -s ion.tpr -nname $ION -nn 1 -p topol.top << EOF
        2
EOF

    # Add iontype to mdp files 
    for mdp in em nvt npt grompp; do
       cp $BASE/input/$mdp.mdp .
       echo "couple-moltype = $ION" >> $mdp.mdp
    done

    # Set up lambda simulations
    gmx_builder free_energy -f em.mdp nvt.mdp npt.mdp grompp.mdp -c out.gro -p topol.top -sub $BASE/srun.sh -d 3 -sp

    rm \#*

    # Create links for dhdl file
    mkdir -p dhdl
    cd dhdl
    for j in $(seq 0 20); do
        ln -sf ../lambda_$j/grompp_$j.xvg md_$j.xvg
    done

    cd ../..
done
cd ../..
done
